<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Français [FR]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=421
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = 'Français';
$lang_info['country'] = 'France';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'fr';
$lang_info['zero_plural'] = false;

$lang['%d Kb'] = '%d Ko';
$lang['%d album updated'] = '%d album mis à jour';
$lang['%d albums updated'] = '%d albums mis à jour';
$lang['%d comment to validate'] = '%d commentaire utilisateur à valider';
$lang['%d comments to validate'] = '%d commentaires utilisateurs à valider';
$lang['%d new comment'] = '%d nouveau commentaire utilisateur';
$lang['%d new comments'] = '%d nouveaux commentaires utilisateurs';
$lang['%d comment'] = '%d commentaire';
$lang['%d comments'] = '%d commentaires';
$lang['%d hit'] = 'vue %d fois';
$lang['%d hits'] = 'vue %d fois';
$lang['%d new photo'] = '%d nouvelle photo';
$lang['%d new photos'] = '%d nouvelles photos';
$lang['%d new user'] = '%d nouvel utilisateur';
$lang['%d new users'] = '%d nouveaux utilisateurs';
$lang['About'] = 'À propos';
$lang['All tags'] = 'Tous les tags';
$lang['Any tag'] = 'N\'importe quel tag';
$lang['At least one listed rule must be satisfied.'] = 'Au moins un des critères doit être satisfait.';
$lang['At least one tag must match'] = 'Au moins un tag doit correspondre';
$lang['Albums'] = 'Albums';
$lang['Album'] = 'Album';
$lang['Close this window'] = 'Fermer cette fenêtre';
$lang['Complete RSS feed (photos, comments)'] = 'Flux RSS complet (photos, commentaires)';
$lang['Confirm Password'] = 'Confirmer le mot de passe';
$lang['Connection settings'] = 'Paramètres de connexion';
$lang['Login'] = 'Connexion';
$lang['Contact webmaster'] = 'Contacter le webmestre';
$lang['Create a new account'] = 'Créer un nouveau compte';
$lang['Created on'] = 'Créée le';
$lang['Creation date'] = 'Date de création';
$lang['Current password is wrong'] = 'Erreur sur le mot de passe actuel';
$lang['Dimensions'] = 'Dimensions';
$lang['Display'] = 'Affichage';
$lang['Each listed rule must be satisfied.'] = 'Chaque critère doit être satisfait';
$lang['Email address'] = 'Adresse e-mail';
$lang['Enter your personnal informations'] = 'Entrer vos informations personnelles';
$lang['Error sending email'] = 'Erreur à l\'envoi du mail';
$lang['File name'] = 'Nom du fichier';
$lang['File'] = 'Fichier';
$lang['Filesize'] = 'Poids';
$lang['Filter and display'] = 'Filtrer et afficher';
$lang['Filter'] = 'Filtre';
$lang['Forgot your password?'] = 'Mot de passe oublié ?';
$lang['Go through the gallery as a visitor'] = 'Parcourir la galerie en tant que visiteur';
$lang['Help'] = 'Aide';
$lang['Identification'] = 'Identification';
$lang['Photos only RSS feed'] = 'Flux RSS des photos uniquement';
$lang['Keyword'] = 'Mot-clef';
$lang['Links'] = 'Liens';
$lang['N/A'] = 'non disponible';
$lang['New on %s'] = 'Nouveau le %s';
$lang['New password confirmation does not correspond'] = 'Erreur de confirmation de mot de passe';
$lang['Notification'] = 'Notifications RSS';
$lang['Number of items'] = 'Nombre d\'élément';
$lang['Original dimensions'] = 'Dimensions d\'origine';
$lang['Password forgotten'] = 'Mot de passe oublié';
$lang['Password'] = 'Mot de passe';
$lang['Post date'] = 'Date d\'ajout';
$lang['Posted on'] = 'Ajoutée le';
$lang['Profile'] = 'Profil';
$lang['Quick connect'] = 'Connexion rapide';
$lang['RSS feed'] = 'flux RSS';
$lang['Register'] = 'S\'enregistrer';
$lang['Registration'] = 'Enregistrement';
$lang['Related tags'] = 'Tags liés';
$lang['Reset'] = 'Annuler';
$lang['Retrieve password'] = 'Récupérer un mot de passe';
$lang['Search rules'] = 'Critères de recherche';
$lang['Search tags'] = 'Rechercher les tags';
$lang['Search'] = 'Recherche';
$lang['display available tags'] = 'Voir les tags disponibles';
$lang['Since'] = 'Depuis';
$lang['Sort by'] = 'Trier selon';
$lang['Sort order'] = 'Ordre de tri';
$lang['Tag'] = 'Tag';
$lang['Tags'] = 'Tags';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'Le flux RSS notifie les événements de la galerie : nouvelles photos, albums mis à jour, nouveaux commentaires utilisateur. À utiliser avec un lecteur de flux RSS.';
$lang['Unknown feed identifier'] = 'Identifiant de flux inconnu';
$lang['User comments'] = 'Commentaires utilisateur';
$lang['Username'] = 'Nom d\'utilisateur';
$lang['Visits'] = 'Visites';
$lang['Webmaster'] = 'Webmestre';
$lang['Week %d'] = 'Semaine %d';
$lang['About Piwigo'] = 'À propos de Piwigo';
$lang['You are not authorized to access the requested page'] = 'Vous n\'êtes pas autorisé à accéder à la page demandée';
$lang['add to caddie'] = 'ajouter au panier';
$lang['add this photo to your favorites'] = 'ajouter cette photo à vos favoris';
$lang['Administration'] = 'Administration';
$lang['all'] = 'tout';
$lang['ascending'] = 'croissant';
$lang['author(s) : %s'] = 'auteur(s) : %s';
$lang['Expand all albums'] = 'Développer tous les albums';
$lang['posted after %s (%s)'] = 'mis en ligne après le %s (%s)';
$lang['posted before %s (%s)'] = 'mis en ligne avant le %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'mis en ligne entre le %s (%s) et le %s (%s)';
$lang['posted on %s'] = 'mis en ligne le %s';
$lang['Best rated'] = 'Mieux notées';
$lang['display best rated photos'] = 'afficher les photos les mieux notées';
$lang['caddie'] = 'Panier';
$lang['Calendar'] = 'Calendrier';
$lang['All'] = 'Tout';
$lang['display each day with photos, month per month'] = 'affichage année par année, mois par mois, jour par jour';
$lang['View'] = 'Vue';
$lang['chronology_monthly_calendar'] = 'Calendrier mensuel';
$lang['chronology_monthly_list'] = 'Liste mensuelle';
$lang['chronology_weekly_list'] = 'Liste hebdomadaire';
$lang['Click here if your browser does not automatically forward you'] = 'Cliquez ici si votre navigateur ne vous redirige pas.';
$lang['comment date'] = 'date du commentaire';
$lang['Comment'] = 'Commentaire';
$lang['Your comment has been registered'] = 'Votre commentaire a été enregistré';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Système anti-abus : merci de patienter avant d\'ajouter un nouveau commentaire';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Votre commentaire n\'a pas été enregistré parce qu\'il ne satisfait aux règles de validation';
$lang['An administrator must authorize your comment before it is visible.'] = 'Un administrateur doit valider votre commentaire pour qu\'il devienne visible.';
$lang['This login is already used by another user'] = 'Ce nom d\'utilisateur est déjà pris';
$lang['Comments'] = 'Commentaires';
$lang['Add a comment'] = 'Ajouter un commentaire';
$lang['created after %s (%s)'] = 'créée après le %s (%s)';
$lang['created before %s (%s)'] = 'créée avant le %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'créée entre le %s (%s) et le %s (%s)';
$lang['created on %s'] = 'créée le %s';
$lang['Customize'] = 'Personnaliser';
$lang['Your Gallery Customization'] = 'Personnalisation de votre affichage ';
$lang['day'][0] = 'Dimanche';
$lang['day'][1] = 'Lundi';
$lang['day'][2] = 'Mardi';
$lang['day'][3] = 'Mercredi';
$lang['day'][4] = 'Jeudi';
$lang['day'][5] = 'Vendredi';
$lang['day'][6] = 'Samedi';
$lang['Default'] = 'Par défaut';
$lang['delete this photo from your favorites'] = 'supprimer cette photo de vos favoris';
$lang['Delete'] = 'Supprimer';
$lang['descending'] = 'décroissant';
$lang['download'] = 'télécharger';
$lang['download this file'] = 'télécharger ce fichier';
$lang['edit'] = 'éditer';
$lang['wrong date'] = 'date erronée';
$lang['excluded'] = 'exclus';
$lang['Your favorites'] = 'Mes favorites';
$lang['display your favorites photos'] = 'afficher mes photos favorites';
$lang['Favorites'] = 'Favoris';
$lang['First'] = 'Première';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'La galerie est verrouillée pour cause de maintenance. Merci de revenir plus tard.';
$lang['Page generated in'] = 'Page fabriquée en';
$lang['guest'] = 'visiteur';
$lang['Hello'] = 'Bonjour';
$lang['available for administrators only'] = 'disponible uniquement pour les administrateurs';
$lang['display this album'] = 'montre les photos à la racine de cet album';
$lang['display last user comments'] = 'Voir les derniers commentaires utilisateurs';
$lang['customize the appareance of the gallery'] = 'personnaliser l\'apparence de la galerie';
$lang['search'] = 'recherche';
$lang['Home'] = 'Accueil';
$lang['in this album'] = 'dans cet album';
$lang['in %d sub-album'] = 'dans %d sous-album';
$lang['in %d sub-albums'] = 'dans %d sous-albums';
$lang['included'] = 'inclus';
$lang['Invalid password!'] = 'Mot de passe invalide !';
$lang['Language'] = 'Langue';
$lang['last %d days'] = '%d derniers jours';
$lang['Last'] = 'Dernière';
$lang['Logout'] = 'Déconnexion';
$lang['E-mail address'] = $lang['Email address'];
$lang['obligatory'] = 'obligatoire';
$lang['Maximum photo height'] = 'Hauteur maximum des photos';
$lang['Maximum height must be a number superior to 50'] = 'La hauteur maximum des photos doit être supérieure à 50';
$lang['Maximum photo width'] = 'Largeur maximum des photos';
$lang['Maximum width must be a number superior to 50'] = 'La largeur des photos doit être supérieure à 50';
$lang['display a calendar by creation date'] = 'afficher un calendrier par date de création';
$lang['display all photos in all sub-albums'] = 'afficher à plat les photos des albums et des sous-albums';
$lang['return to normal view mode'] = 'retourner à la vue normale';
$lang['display a calendar by posted date'] = 'afficher un calendrier par date d\'ajout';
$lang['month'][10] = 'Octobre';
$lang['month'][11] = 'Novembre';
$lang['month'][12] = 'Décembre';
$lang['month'][1] = 'Janvier';
$lang['month'][2] = 'Février';
$lang['month'][3] = 'Mars';
$lang['month'][4] = 'Avril';
$lang['month'][5] = 'Mai';
$lang['month'][6] = 'Juin';
$lang['month'][7] = 'Juillet';
$lang['month'][8] = 'Août';
$lang['month'][9] = 'Septembre';
$lang['Most visited'] = 'Plus vues';
$lang['display most visited photos'] = 'afficher les photos les plus vues';
$lang['The number of photos per page must be a not null scalar'] = 'Le nombre de photos par page doit être un entier non nul';
$lang['Number of photos per page'] = 'Nombre de miniatures par page';
$lang['Unknown identifier'] = 'Identifiants inconnus';
$lang['New password'] = 'Nouveau mot de passe';
$lang['Rate this photo'] = 'Votez pour cette photo';
$lang['Next'] = 'Suivante';
$lang['no rate'] = 'pas de note';
$lang['Photos posted within the last %d day.'] = 'N\'afficher que les photos récentes de moins de %d jour.';
$lang['Photos posted within the last %d days.'] = 'N\'afficher que les photos récentes de moins de %d jours.';
$lang['password updated'] = 'mot de passe mis à jour';
$lang['Recent period must be a positive integer value'] = 'La période de nouveautés doit être un entier positif';
$lang['photo'] = 'photo';
$lang['Click on the photo to see it in high definition'] = 'Cliquer sur la photo pour la visualiser en haute définition';
$lang['Show file metadata'] = 'Montrer les méta-données du fichier';
$lang['Powered by'] = 'Propulsé par';
$lang['Preferences'] = 'Préférences';
$lang['Previous'] = 'Précédente';
$lang['Random photos'] = 'Photos au hasard';
$lang['display a set of random photos'] = 'afficher un ensemble de photos prises au hasard';
$lang['Recent albums'] = 'Albums récents';
$lang['display recently updated albums'] = 'afficher les albums récemment mis à jour ou créés';
$lang['Recent period'] = 'Période récente';
$lang['Recent photos'] = 'Photos récentes';
$lang['display most recent photos'] = 'afficher les photos les plus récentes';
$lang['Redirection...'] = 'Redirection...';
$lang['Please, enter a login'] = 'S\'il vous plaît, entrez un nom d\'utilisateur';
$lang['login mustn\'t end with a space character'] = 'le nom d\'utilisateur ne doit pas se terminer par un espace';
$lang['login mustn\'t start with a space character'] = 'le nom d\'utilisateur ne doit pas commencer par un espace';
$lang['this login is already used'] = 'ce nom d\'utilisateur est déjà pris';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'l\'adresse e-mail doit être de la forme xxx@yyy.eee (exemple : jack@altern.org)';
$lang['please enter your password again'] = 'Merci d\'entrer à nouveau votre mot de passe';
$lang['Auto login'] = 'Connexion auto';
$lang['remove this tag from the list'] = 'retirer ce tag de la liste';
$lang['representative'] = 'représentante';
$lang['Search for Author'] = 'Rechercher un auteur';
$lang['Search in albums'] = 'Rechercher dans les albums';
$lang['Search by Date'] = 'Recherche par date';
$lang['Date'] = 'Date';
$lang['End-Date'] = 'Date de fin';
$lang['Kind of date'] = 'Type de date';
$lang['Search for words'] = 'Recherche de mots';
$lang['Search for all terms'] = 'Rechercher tous les mots';
$lang['Search for any terms'] = 'Rechercher un des mots';
$lang['Empty query. No criteria has been entered.'] = 'Requête vide. Aucun critère saisi.';
$lang['Search Options'] = 'Options de recherche';
$lang['Search results'] = 'Résultats de recherche';
$lang['Search in sub-albums'] = 'Rechercher dans les sous-albums';
$lang['searched words : %s'] = 'mots recherchés : %s';
$lang['Contact'] = 'Contacter';
$lang['set as album representative'] = 'Choisir comme représentante de cet album';
$lang['Show number of comments'] = 'Montrer le nombre de commentaires';
$lang['Show number of hits'] = 'Montrer le nombre de visualisations';
$lang['slideshow'] = 'diaporama';
$lang['stop the slideshow'] = 'arrêter le diaporama';
$lang['Specials'] = 'Spéciales';
$lang['SQL queries in'] = 'requêtes SQL en';
$lang['display only recently posted photos'] = 'n\'afficher que les photos publiées récemment';
$lang['return to the display of all photos'] = 'retourner à l\'affichage de toutes les photos';
$lang['the beginning'] = 'le début';
$lang['Interface theme'] = 'Thème de l\'interface';
$lang['Thumbnails'] = 'Miniatures';
$lang['Menu'] = 'Menu';
$lang['A comment on your site'] = 'Un commentaire sur le site';
$lang['today'] = 'aujourd\'hui';
$lang['Update your rating'] = 'Mettre à jour votre note';
$lang['wrong filename'] = 'mauvais nom de fichier';
$lang['the username must be given'] = 'le nom d\'utilisateur doit être indiqué';
$lang['useful when password forgotten'] = 'utile en cas d\'oubli de mot de passe';
$lang['Quick search'] = 'Recherche rapide';
$lang['Connected user: %s'] = 'Utilisateur connecté : %s';
$lang['IP: %s'] = 'IP : %s';
$lang['Browser: %s'] = 'Navigateur : %s';
$lang['Author: %s'] = 'Auteur : %s';
$lang['Comment: %s'] = 'Commentaire : %s';
$lang['Comment by %s'] = 'Commentaire par %s';
$lang['User: %s'] = 'Utilisateur: %s';
$lang['Email: %s'] = 'Email : %s';
$lang['Admin: %s'] = 'Administration : %s';
$lang['Registration of %s'] = 'Enregistrement de %s';
$lang['Album: %s'] = 'Album : %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Statut de l\'utilisateur "guest" non conforme, utilisation du statut par défaut. Veuillez prévenir le webmestre.';
$lang['this email address is already in use'] = 'un autre utilisateur utilise déjà cette adresse e-mail';
$lang['Album results for'] = 'Résultats des albums pour';
$lang['Tag results for'] = 'Résultats des tags pour';
$lang['from %s to %s'] = 'du %s au %s';
$lang['Play of slideshow'] = 'Lecture du diaporama';
$lang['Pause of slideshow'] = 'Pause du diaporama';
$lang['Repeat the slideshow'] = 'Répéter le diaporama';
$lang['Not repeat the slideshow'] = 'Ne pas répéter le diaporama';
$lang['Reduce diaporama speed'] = 'Ralentir la vitesse du diaporama';
$lang['Accelerate diaporama speed'] = 'Accélerer la vitesse du diaporama';
$lang['Submit'] = 'Valider';
$lang['Yes'] = 'Oui';
$lang['No'] = 'Non';
$lang['%d photo'] = '%d photo';
$lang['%d photos'] = '%d photos';
$lang['%d photo is also linked to current tags'] = '%d photo est également liée aux tags courants';
$lang['%d photos are also linked to current tags'] = '%d photos sont également liées aux tags courants';
$lang['display photos linked to this tag'] = 'Voir les photos liées uniquement à ce tag';
$lang['photos posted during the last %d days'] = 'photos ajoutées au cours des %d derniers jours';
$lang['Piwigo Help'] = 'Aide de Piwigo';
$lang['Rank'] = 'Rang';
$lang['group by letters'] = 'regrouper par lettres';
$lang['letters'] = 'lettres';
$lang['show tag cloud'] = 'montrer le nuage de tags';
$lang['cloud'] = 'nuage';
$lang['Reset to default values'] = 'Rétablir les valeurs par défaut';
$lang['delete all photos from your favorites'] = 'supprimer toutes les photos de vos favoris';
$lang['Sent by'] = 'Envoyé par';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Les cookies sont bloqués ou non supportés par votre navigateur web. Vous devez activer les cookies pour vous connecter.';
$lang['edit this comment'] = "éditer ce commentaire";
$lang['Edit a comment'] = "Éditer un commentaire";
$lang['Are you sure?'] = "Etes-vous sûr ?";
$lang['(!) This comment requires validation'] = '(!) Ce commentaire doit être validé';
$lang['Welcome'] = 'Bienvenue';
$lang['Welcome to your Piwigo photo gallery!'] = 'Bienvenue sur votre galerie photo Piwigo !';
$lang['... or browse your empty gallery'] = '... ou naviguez sur votre galerie vide';
$lang['... or please deactivate this message, I will find my way by myself'] = '... ou désactivez ce message, je me débrouillerai par moi-même';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Bonjour %s, votre galerie photo Piwigo est vide !';
$lang['I want to add photos'] = 'Je veux ajouter des photos';
$lang['Manage this user comment: %s'] = 'Gérer ce commentaire : %s';
$lang['Email address is missing. Please specify an email address.'] = "L'adresse email manque. Veuillez spécifier une adresse email.";
$lang['This author modified following comment:'] = 'Cet auteur a modifié le commentaire suivant :';
$lang['This author removed the comment with id %d'] = 'Cet auteur a supprimé le commentaire portant l\'identifiant %d';
$lang['delete this comment'] = "supprimer ce commentaire";
$lang['validate this comment'] = 'valider ce commentaire';
$lang['html tags are not allowed in login'] = 'les balises html ne sont pas autorisées dans le login';
$lang['Enter a username or email address'] = 'Entrez votre nom d\'utilisateur ou votre adresse email';
$lang['Invalid username or email'] = 'Nom d\'utilisateur ou adresse email invalide';
$lang['Password reset is not allowed for this user'] = 'Le renouvellement du mot de passe n\'est pas permise pour cet utilisateur';
$lang['User "%s" has no email address, password reset is not possible'] = 'L\'utilisateur "%s" n\'a pas d\'adresse email, le renouvellement du mot de passe est impossible';
$lang['Someone requested that the password be reset for the following user account:'] = 'Quelqu\'un a demandé le renouvellement de votre mot de passe pour l\'utilisateur suivant :';
$lang['Username "%s" on gallery %s'] = 'Utilisateur "%s" sur la galerie %s';
$lang['To reset your password, visit the following address:'] = 'Pour renouveler votre mot de passe, cliquez sur le lien suivant :';
$lang['If this was a mistake, just ignore this email and nothing will happen.'] = 'S\'il s\'agit d\'une erreur, ignorez ce message et la demande ne sera pas prise en compte.';
$lang['Password Reset'] = 'Renouvellement de votre mot de passe';
$lang['Check your email for the confirmation link'] = 'Vérifiez vos emails pour trouver le lien de confirmation';
$lang['Invalid key'] = 'Clef invalide';
$lang['The passwords do not match'] = 'Les mots de passe ne correspondent pas';
$lang['Your password has been reset'] = 'Votre mot de passe a été réinitialisé';
$lang['Return to home page'] = 'Retourner sur la page d\'accueil';
$lang['Please enter your username or email address.'] = 'Merci d\'entrer votre nom d\'utilisateur ou votre adresse email.';
$lang['You will receive a link to create a new password via email.'] = 'Par email, vous recevrez un lien à cliquer pour renouveler votre mot de passe.';
$lang['Username or email'] = 'Nom d\'utilisateur ou adresse email';
$lang['Change my password'] = 'Changer mon mot de passe';
$lang['Enter your new password below.'] = 'Entrez votre nouveau mot de passe ci-dessous.';
$lang['Author'] = 'Auteur';
$lang['%d rates'] = '%d notes';
$lang['Rating score'] = 'Score';
$lang['Reset Password'] = 'Réinitialiser le mot de passe';
$lang['EXIF Metadata'] = 'Données EXIF';
$lang['IPTC Metadata'] = 'Données IPTC';

?>